@@ -1,11 +1,11 @@
 from .sqlee import Sqlee
 
 __name__ = "sqlee"
-__version__ = "1.2.0"
+__version__ = "1.2.1"
 __all__ = [
     'connect', 'utils',
     ]
-__author__ = "Entropy/Bash <fu050409@163.com/3141495167@qq.com>"
+__author__ = "Entropy <fu050409@163.com>"
 __incantation__ = "嗡嘛呢叭咪吽"
 
 def connect(token=None, repo=None, owner=None):
